@@ -148,23 +148,6 @@ details:
 	}
 }
 
-func TestHipchatRoomIDIsPresent(t *testing.T) {
-	in := `
-room_id: ''
-`
-	var cfg HipchatConfig
-	err := yaml.UnmarshalStrict([]byte(in), &cfg)
-
-	expected := "missing room id in Hipchat config"
-
-	if err == nil {
-		t.Fatalf("no error returned, expected:\n%v", expected)
-	}
-	if err.Error() != expected {
-		t.Errorf("\nexpected:\n%v\ngot:\n%v", expected, err.Error())
-	}
-}
-
 func TestWebhookURLIsPresent(t *testing.T) {
 	in := `{}`
 	var cfg WebhookConfig
@@ -212,7 +195,7 @@ url: 'http://example.com'
 	}
 }
 
-func TestWebhookPasswordIsObsfucated(t *testing.T) {
+func TestWebhookPasswordIsObfuscated(t *testing.T) {
 	in := `
 url: 'http://example.com'
 http_config:
@@ -453,7 +436,7 @@ fields:
 	}
 }
 
-func TestSlackFieldConfigUnmarshalling(t *testing.T) {
+func TestSlackFieldConfigUnmarshaling(t *testing.T) {
 	in := `
 fields:
 - title: first
